@@ -25,7 +25,6 @@
 #include <QDesktopWidget>
 #include <QPushButton>
 #include <QStyleOption>
-#include <QTextDocument>
 #include <QTimer>
 
 #include <ktitlewidget.h>
@@ -39,7 +38,6 @@ public:
     KPasswordDialogPrivate(KPasswordDialog *q)
         : q(q),
           userEditCombo(nullptr),
-          pixmapLabel(nullptr),
           commentRow(0)
     {}
 
@@ -53,7 +51,7 @@ public:
     Ui_KPasswordDialog ui;
     QMap<QString, QString> knownLogins;
     QComboBox *userEditCombo;
-    QLabel *pixmapLabel;
+    QIcon icon;
     KPasswordDialogFlags m_flags;
     unsigned int commentRow;
 };
@@ -93,7 +91,8 @@ void KPasswordDialog::KPasswordDialogPrivate::init()
     if (m_flags & KPasswordDialog::ShowUsernameLine) {
         ui.userEdit->setFocus();
         ui.credentialsGroup->setFocusProxy(ui.userEdit);
-        QObject::connect(ui.userEdit, SIGNAL(returnPressed()), ui.passEdit, SLOT(setFocus()));
+        QObject::connect(ui.userEdit, &QLineEdit::returnPressed,
+                         ui.passEdit, QOverload<>::of(&QWidget::setFocus));
     } else {
         ui.userNameLabel->hide();
         ui.userEdit->hide();
@@ -101,6 +100,8 @@ void KPasswordDialog::KPasswordDialogPrivate::init()
         ui.domainEdit->hide();
         ui.passEdit->setFocus();
         ui.credentialsGroup->setFocusProxy(ui.passEdit);
+        ui.prompt->setText(QApplication::translate("KPasswordDialog",
+                    "Supply a password below."));
     }
 
     if (!(m_flags & KPasswordDialog::ShowAnonymousLoginCheckBox)) {
@@ -121,30 +122,32 @@ void KPasswordDialog::KPasswordDialogPrivate::init()
 
     QRect desktop = QApplication::desktop()->screenGeometry(q->topLevelWidget());
     q->setMinimumWidth(qMin(1000, qMax(q->sizeHint().width(), desktop.width() / 4)));
+    q->setIcon(QIcon::fromTheme(QStringLiteral("dialog-password")));
+}
+
+void KPasswordDialog::setIcon(const QIcon &icon)
+{
+    d->icon = icon;
+
     QStyleOption option;
-    option.initFrom(q);
-    const int iconSize = q->style()->pixelMetric(QStyle::PM_MessageBoxIconSize, &option, q);
-    q->setPixmap(QIcon::fromTheme(QStringLiteral("dialog-password")).pixmap(iconSize));
+    option.initFrom(this);
+    const int iconSize = style()->pixelMetric(QStyle::PM_MessageBoxIconSize, &option, this);
+    d->ui.pixmapLabel->setPixmap(icon.pixmap(iconSize));
+}
+
+QIcon KPasswordDialog::icon() const
+{
+    return d->icon;
 }
 
 void KPasswordDialog::setPixmap(const QPixmap &pixmap)
 {
-    if (!d->pixmapLabel) {
-        d->pixmapLabel = new QLabel(this);
-        d->pixmapLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
-        d->ui.hboxLayout->insertWidget(0, d->pixmapLabel);
-    }
-
-    d->pixmapLabel->setPixmap(pixmap);
+    d->ui.pixmapLabel->setPixmap(pixmap);
 }
 
 QPixmap KPasswordDialog::pixmap() const
 {
-    if (!d->pixmapLabel) {
-        return QPixmap();
-    }
-
-    return *d->pixmapLabel->pixmap();
+    return *d->ui.pixmapLabel->pixmap();
 }
 
 void KPasswordDialog::setUsername(const QString &user)
@@ -348,7 +351,8 @@ void KPasswordDialog::setKnownLogins(const QMap<QString, QString> &knownLogins)
         setTabOrder(d->ui.anonymousRadioButton, d->ui.domainEdit);
         setTabOrder(d->ui.domainEdit, d->ui.passEdit);
         setTabOrder(d->ui.passEdit, d->ui.keepCheckBox);
-        connect(d->ui.userEdit, SIGNAL(returnPressed()), d->ui.passEdit, SLOT(setFocus()));
+        connect(d->ui.userEdit, &QLineEdit::returnPressed,
+                d->ui.passEdit, QOverload<>::of(&QWidget::setFocus));
     }
 
     d->knownLogins = knownLogins;
@@ -381,7 +385,7 @@ void KPasswordDialog::accept()
 
     // we do this to allow the error message, if any, to go away
     // checkPassword() may block for a period of time
-    QTimer::singleShot(0, this, SLOT(actuallyAccept()));
+    QTimer::singleShot(0, this, [this] { d->actuallyAccept(); });
 }
 
 void KPasswordDialog::KPasswordDialogPrivate::actuallyAccept()
